/*
  Copyright 1999 Brian H. Trammell (brian@altara.org)
  
  This software (and its source code) are freely usable, modifiable, 
  and redistributable under the terms of the GNU General Public License, 
  available at http://www.gnu.org/copyleft/gpl.html, and in the ./COPYING 
  file in the MARS distribution.
*/

package org.altara.mars;

import javax.swing.*;
import java.awt.*;

/**
   Implements the Welcome to MARS splash screen. This fulfills Section 2(c) 
   of the GNU General Public License, expecially on Windows machines where 
   standard output may be discarded.
*/

// Revision 1.4.5 13 May 1999 - added to MARS
// Revision 1.4.6 16 May 1999 - added title

public class MARSWelcome extends JDialog {
    
    /** How long to display the welcome box, in milliseconds */
    public final static long DISPLAYTIME = 3000;
    
    /**
       Default constructor. Add all necessary components.
    */
    
    public MARSWelcome() {

	/* Set the dialog title */
	setTitle("Welcome to MARS");

	/* Create the MARS icon */
	ImageIcon marsIcon = new ImageIcon("images/Mars.gif");
	JLabel marsIconLabel = new JLabel(marsIcon);
	marsIconLabel.setHorizontalAlignment(SwingConstants.CENTER);

	/* Create the version identity string */
	JLabel marsVersion = new JLabel("MARS version "+MARS.VERSION);
	marsVersion.setHorizontalAlignment(SwingConstants.CENTER);

	/* Create the copyright string */
	JLabel marsCopyright = new JLabel("(c) 1999 Brian H. Trammell");
	marsCopyright.setHorizontalAlignment(SwingConstants.CENTER);

	/* Create the GPL notification */
	JLabel marsGPL1 = new JLabel("MARS is released without any warranty,");
	JLabel marsGPL2 = new JLabel("and is distributed under the terms of");
	JLabel marsGPL3 = new JLabel("the GNU General Public License,");
	JLabel marsGPL4 = new JLabel("available at http://www.gnu.org/copyleft/gpl.html");
	marsGPL1.setHorizontalAlignment(SwingConstants.CENTER);
	marsGPL2.setHorizontalAlignment(SwingConstants.CENTER);
	marsGPL3.setHorizontalAlignment(SwingConstants.CENTER);
	marsGPL4.setHorizontalAlignment(SwingConstants.CENTER);

	/* Lay out the dialog */
	getContentPane().setLayout(new GridLayout(2,1));
	getContentPane().add(marsIconLabel);
	JPanel textPanel = new JPanel(new GridLayout(6,1));
        textPanel.add(marsVersion);
        textPanel.add(marsCopyright);
        textPanel.add(marsGPL1);
	textPanel.add(marsGPL2);
	textPanel.add(marsGPL3);
	textPanel.add(marsGPL4);
	getContentPane().add(textPanel);

	/* Add the box to the dialog */
	this.pack();
    }

    /** 
       Display the welcome message by making the window visible for 
       1 second.
    */

    public void displayWelcome() {
	setVisible(true);
	try {
	    Thread.currentThread().sleep(DISPLAYTIME);
	} catch (Exception ex) {}
	setVisible(false);
    }
}




